@@ -38,6 +38,7 @@
 #include "diagram_tree_window.h"
 #include "object_ops.h"
 #include "sheets.h"
+#include "dia-app-icons.h"
 
 static void plugin_callback (GtkWidget *widget, gpointer data);
 
@@ -52,15 +53,18 @@ static GtkItemFactoryEntry toolbox_menu_items[] =
       "<StockItem>", GTK_STOCK_NEW },
   {N_("/File/_Open..."),       "<control>O", file_open_callback,        0,
       "<StockItem>", GTK_STOCK_OPEN },
+/*  {N_("/Open _Recent"),           NULL,         NULL,           0, "<Branch>"}, */
+/*  {   "/Open Recent/tearoff",     NULL,         NULL,         0, "<Tearoff>" }, */
   {N_("/File/---"),            NULL,         NULL,       0, "<Separator>" },
-  {N_("/File/_Diagram tree"),  NULL,         diagtree_show_callback,    0,
+  {N_("/File/_Diagram tree"),  "F8",         diagtree_show_callback,    0,
    "<ToggleItem>" },
   {N_("/File/Sheets and Objects..."),
-                               NULL,         sheets_dialog_show_callback, 0 },
+                               "F9",         sheets_dialog_show_callback, 0 },
   {N_("/File/---"),            NULL,         NULL,       0, "<Separator>" },
  {N_("/File/_Preferences..."),NULL,         file_preferences_callback, 0,
       "<StockItem>", GTK_STOCK_PREFERENCES },
-   {N_("/File/P_lugins..."),   NULL,         file_plugins_callback,     0 },
+   {N_("/File/P_lugins..."),   NULL,         file_plugins_callback,     0,
+      "<StockItem>", GTK_STOCK_EXECUTE },
   {N_("/File/---"),            NULL,         NULL,       0, "<Separator>" },
     /* recent file list is dynamically inserted here */
   {N_("/File/---"),            NULL,         NULL,       0, "<Separator>" },
@@ -68,10 +72,10 @@ static GtkItemFactoryEntry toolbox_menu_items[] =
       "<StockItem>", GTK_STOCK_QUIT },
   {N_("/_Help"),               NULL,         NULL,       0,    "<Branch>" },
   {   "/Help/tearoff",         NULL,         NULL,       0,   "<Tearoff>" },
-  {N_("/Help/_Manual"),        "F1",         help_manual_callback,      0,
+  {N_("/Help/_Contents"),        "F1",         help_manual_callback,      0,
       "<StockItem>", GTK_STOCK_HELP },
   {N_("/Help/---"),            NULL,         NULL,       0, "<Separator>" },
-  {N_("/Help/_About..."),      NULL,         help_about_callback,       0 },
+  {N_("/Help/_About..."),      NULL,         help_about_callback,       0 }
 };
 
 /* calculate the number of menu_item's */
@@ -87,11 +91,15 @@ static GtkItemFactoryEntry display_menu_items[] =
       "<StockItem>", GTK_STOCK_NEW },
   {N_("/File/_Open..."),          "<control>O", file_open_callback,         0,
       "<StockItem>", GTK_STOCK_OPEN },
+/*  {N_("/Open _Recent"),           NULL,         NULL,           0, "<Branch>"}, */
+/*  {   "/Open Recent/tearoff",     NULL,         NULL,         0, "<Tearoff>" }, */
+  {N_("/File/---"),               NULL,         NULL,        0, "<Separator>"},
   {N_("/File/_Save"),             "<control>S", file_save_callback,         0,
       "<StockItem>", GTK_STOCK_SAVE },
   {N_("/File/Save _As..."),       "<control><shift>S", file_save_as_callback,      0,
       "<StockItem>", GTK_STOCK_SAVE_AS },
-  {N_("/File/_Export..."),        NULL,         file_export_callback,       0},
+  {N_("/File/_Export..."),        NULL,         file_export_callback,         0,
+      "<StockItem>", GTK_STOCK_CONVERT},
   {N_("/File/---"),               NULL,         NULL,        0, "<Separator>"},
   {N_("/File/Page Set_up..."),    NULL,         file_pagesetup_callback,    0},
   {N_("/File/_Print Diagram..."), "<control>P", file_print_callback,        0,
@@ -119,12 +127,17 @@ static GtkItemFactoryEntry display_menu_items[] =
   {N_("/Edit/_Delete"),           "Delete", edit_delete_callback,       0,
       "<StockItem>", GTK_STOCK_DELETE },
   {N_("/Edit/---"),            NULL,         NULL,       0, "<Separator>" },
-  {N_("/Edit/Copy Text"),         NULL,         edit_copy_text_callback,    0},
-  {N_("/Edit/Cut Text"),          NULL,         edit_cut_text_callback,     0},
-  {N_("/Edit/Paste _Text"),       NULL,         edit_paste_text_callback,   0},
+  /* the following used to bind to <control><shift>C which collides with Unicode input. <control>>alt> doesn't work either */
+  {N_("/Edit/Copy Text"),      NULL,         edit_copy_text_callback,    0,
+      "<StockItem>", GTK_STOCK_COPY },
+  {N_("/Edit/Cut Text"),       "<control><shift>X",         edit_cut_text_callback,     0,
+      "<StockItem>", GTK_STOCK_CUT },
+  {N_("/Edit/Paste _Text"),    "<control><shift>V",         edit_paste_text_callback,   0,
+      "<StockItem>", GTK_STOCK_PASTE },
   {N_("/_Diagram"),               NULL,         NULL,           0, "<Branch>"},
   {   "/Diagram/tearoff",            NULL,         NULL,         0, "<Tearoff>" },
-  {N_("/Diagram/_Properties..."), NULL,         view_diagram_properties_callback, 0},
+  {N_("/Diagram/_Properties..."), NULL,         view_diagram_properties_callback,          0,
+      "<StockItem>", GTK_STOCK_PROPERTIES},
   {N_("/Diagram/_Layers..."),     NULL,     dialogs_layers_callback,        0},
   {N_("/_View"),                  NULL,         NULL,           0, "<Branch>"},
   {   "/View/tearoff",            NULL,         NULL,         0, "<Tearoff>" },
@@ -134,6 +147,8 @@ static GtkItemFactoryEntry display_menu_items[] =
       "<StockItem>", GTK_STOCK_ZOOM_OUT },
   {N_("/View/_Zoom"),             NULL,         NULL,           0, "<Branch>"},
   {   "/View/Zoom/tearoff",       NULL,         NULL,         0, "<Tearoff>" },
+  {N_("/View/Zoom/1600%"),        NULL,         view_zoom_set_callback,  16000},
+  {N_("/View/Zoom/800%"),         NULL,         view_zoom_set_callback,  8000},
   {N_("/View/Zoom/400%"),         "<alt>4",     view_zoom_set_callback,  4000},
   {N_("/View/Zoom/283%"),         NULL,         view_zoom_set_callback,  2828},
   {N_("/View/Zoom/200%"),         "<alt>2",     view_zoom_set_callback,  2000},
@@ -146,28 +161,39 @@ static GtkItemFactoryEntry display_menu_items[] =
   {N_("/View/Zoom/35.4%"),        NULL,         view_zoom_set_callback,   354},
   {N_("/View/Zoom/25%"),          NULL,         view_zoom_set_callback,   250},
   {N_("/View/---"),            NULL,         NULL,       0, "<Separator>" },
+  {N_("/View/Fullscr_een"),      "F11",        view_fullscreen_callback,   0, "<ToggleItem>"},
 #ifdef HAVE_LIBART  
   {N_("/View/_AntiAliased"),      NULL,         view_aa_callback,           0, "<ToggleItem>"},
 #endif
   {N_("/View/Show _Grid"),     NULL,         view_visible_grid_callback, 0, "<ToggleItem>"},
   {N_("/View/_Snap To Grid"),     NULL,         view_snap_to_grid_callback, 0, "<ToggleItem>"},
+  {N_("/View/Snap To _Objects"),     NULL,         view_snap_to_objects_callback, 0, "<ToggleItem>"},
   {N_("/View/Show _Rulers"),      NULL,         view_toggle_rulers_callback,0, "<ToggleItem>"},
   {N_("/View/Show _Connection Points"),	  NULL,		view_show_cx_pts_callback,   0,	"<ToggleItem>"},
   {N_("/View/---"),               NULL,         NULL,        0, "<Separator>"},
   {N_("/View/New _View"),         NULL, view_new_view_callback,     0},
+  {N_("/View/C_lone View"),       NULL, view_clone_view_callback,   0},
   /* Show All, Best Fit.  Same as the Gimp, Ctrl+E */
-  {N_("/View/Show _All"),         "<control>E", view_show_all_callback,     0},
-  {N_("/View/Re_draw"),           NULL,         view_redraw_callback,       0},
+  {N_("/View/Show _All"),         "<control>E", view_show_all_callback,     0,
+      "<StockItem>", GTK_STOCK_ZOOM_FIT },
+  {N_("/View/Re_draw"),           NULL,         view_redraw_callback,       0,
+      "<StockItem>", GTK_STOCK_REFRESH },
   {N_("/_Objects"),               NULL,         NULL,           0, "<Branch>"},
   {   "/Objects/tearoff",         NULL,         NULL,         0, "<Tearoff>" },
-  {N_("/Objects/Send to _Back"),  "<control>B",objects_place_under_callback,0},
-  {N_("/Objects/Bring to _Front"),"<control>F", objects_place_over_callback,0},
-  {N_("/Objects/Send Backwards"),  "<control><shift>B",objects_place_down_callback,0},
-  {N_("/Objects/Bring Forwards"),"<control><shift>F", objects_place_up_callback,0},
+  {N_("/Objects/Send to _Back"),  "<control>B",objects_place_under_callback, 0,
+      "<StockItem>", GTK_STOCK_GOTO_BOTTOM },
+  {N_("/Objects/Bring to _Front"),"<control>F", objects_place_over_callback,0,
+      "<StockItem>", GTK_STOCK_GOTO_TOP},
+  {N_("/Objects/Send Backwards"),  NULL, objects_place_down_callback,0,
+      "<StockItem>", GTK_STOCK_GO_DOWN},
+  {N_("/Objects/Bring Forwards"), NULL, objects_place_up_callback,0,
+      "<StockItem>", GTK_STOCK_GO_UP},
   {N_("/Objects/---"),            NULL,         NULL,        0, "<Separator>"},
-  {N_("/Objects/_Group"),         "<control>G", objects_group_callback,     0},
+  {N_("/Objects/_Group"),         "<control>G", objects_group_callback,     0, 
+  "<ImageItem>", dia_group_icon},
   /* deliberately not using Ctrl+U for Ungroup */
-  {N_("/Objects/_Ungroup"),       "<control><shift>G", objects_ungroup_callback,   0}, 
+  {N_("/Objects/_Ungroup"),       "<control><shift>G", objects_ungroup_callback, 0,
+  "<ImageItem>", dia_ungroup_icon}, 
   {N_("/Objects/---"),            NULL,         NULL,        0, "<Separator>"},
   {N_("/Objects/_Parent"),         "<control>L", objects_parent_callback,     0},
   {N_("/Objects/_Unparent"),       "<control><shift>L", objects_unparent_callback,   0},
@@ -175,9 +201,13 @@ static GtkItemFactoryEntry display_menu_items[] =
   {N_("/Objects/---"),            NULL,         NULL,        0, "<Separator>"},
   {N_("/Objects/Align"),       NULL, NULL,          0, "<Branch>"},
   {   "/Objects/Align/tearoff", NULL, NULL,        0, "<Tearoff>" },
-  {N_("/Objects/Align/Left"),   NULL, objects_align_h_callback,  DIA_ALIGN_LEFT},
-  {N_("/Objects/Align/Center"), NULL, objects_align_h_callback,  DIA_ALIGN_CENTER},
-  {N_("/Objects/Align/Right"),  NULL, objects_align_h_callback,  DIA_ALIGN_RIGHT},
+  {N_("/Objects/Align/Left"),   NULL, objects_align_h_callback,  DIA_ALIGN_LEFT,
+      "<StockItem>", GTK_STOCK_JUSTIFY_LEFT },
+  {N_("/Objects/Align/Center"), NULL, objects_align_h_callback,  DIA_ALIGN_CENTER,
+      "<StockItem>", GTK_STOCK_JUSTIFY_CENTER},
+  {N_("/Objects/Align/Right"),  NULL, objects_align_h_callback,  DIA_ALIGN_RIGHT,
+      "<StockItem>", GTK_STOCK_JUSTIFY_RIGHT},
+  {N_("/Objects/Align/---"),            NULL,         NULL,        0, "<Separator>"},
   {N_("/Objects/Align/Top"),      NULL, objects_align_v_callback,  DIA_ALIGN_TOP},
   {N_("/Objects/Align/Middle"),   NULL, objects_align_v_callback,  DIA_ALIGN_CENTER},
   {N_("/Objects/Align/Bottom"),   NULL, objects_align_v_callback,  DIA_ALIGN_BOTTOM},
@@ -187,25 +217,28 @@ static GtkItemFactoryEntry display_menu_items[] =
   {N_("/Objects/Align/Adjacent"), NULL, objects_align_h_callback,    DIA_ALIGN_ADJACENT},
   {N_("/Objects/Align/Stacked"), NULL, objects_align_v_callback,  DIA_ALIGN_ADJACENT},
   {N_("/Objects/---"),            NULL,     NULL,                           0, "<Separator>"},
-  {N_("/Objects/_Properties..."), NULL,     dialogs_properties_callback,    0},
+  {N_("/Objects/_Properties..."), NULL,     dialogs_properties_callback,         0,
+      "<StockItem>", GTK_STOCK_PROPERTIES},
   {N_("/_Select"),                NULL,         NULL,           0, "<Branch>"},
   {   "/Select/tearoff",          NULL,         NULL,         0, "<Tearoff>" },
   {N_("/Select/All"),             "<control>A", select_all_callback,        0},
-  {N_("/Select/None"),            "<ctrl><shift>A", select_none_callback,   0},
-  {N_("/Select/Invert"),          NULL,         select_invert_callback,     0},
-  {N_("/Select/Connected"),       NULL,         select_connected_callback,  0},
+  {N_("/Select/None"),            NULL, select_none_callback,   0},
+  {N_("/Select/Invert"),          "<control>I",         select_invert_callback,     0},
+  {N_("/Select/---"),             NULL,         NULL,        0, "<Separator>"},
   {N_("/Select/Transitive"),      "<control>T", select_transitive_callback, 0},
+  {N_("/Select/Connected"),       "<control><shift>T",         select_connected_callback,  0},
   {N_("/Select/Same Type"),       NULL,         select_same_type_callback,  0},
   {N_("/Select/---"),             NULL,         NULL,        0, "<Separator>"},
   {N_("/Select/Replace"),       NULL, select_style_callback,
    SELECT_REPLACE, "<RadioItem>"},
   {N_("/Select/Union"),     NULL, select_style_callback,
    SELECT_UNION, "/Select/Replace"},
-  {N_("/Select/Intersect"), NULL, select_style_callback,
+  {N_("/Select/Intersection"), NULL, select_style_callback,
    SELECT_INTERSECTION, "/Select/Replace"},
   {N_("/Select/Remove"),    NULL, select_style_callback,
    SELECT_REMOVE, "/Select/Replace"},
-  {N_("/Select/Invert"),    NULL, select_style_callback,
+  /* Cannot also be called Invert, duplicate names caused keybinding problems */
+  {N_("/Select/Inverse"),    NULL, select_style_callback,
    SELECT_INVERT, "/Select/Replace"},
   {N_("/_Tools"),                 NULL,     NULL,               0, "<Branch>"},
   {   "/Tools/tearoff",           NULL,     NULL,         0, "<Tearoff>" },
@@ -229,10 +262,11 @@ static GtkItemFactoryEntry display_menu_items[] =
   {   "/Input Methods/tearoff",   NULL,     NULL,               0, "<Tearoff>" },
   {N_("/_Help"),               NULL,         NULL,       0,    "<Branch>" },
   {   "/Help/tearoff",         NULL,         NULL,       0,   "<Tearoff>" },
-  {N_("/Help/_Manual"),        "F1",         help_manual_callback,      0,
+  {N_("/Help/_Contents"),        "F1",         help_manual_callback,      0,
       "<StockItem>", GTK_STOCK_HELP },
   {N_("/Help/---"),            NULL,         NULL,       0, "<Separator>" },
-  {N_("/Help/_About..."),      NULL,         help_about_callback,       0 },
+  {N_("/Help/_About..."),      NULL,         help_about_callback,       0,
+   /* FOR 2.6 "<StockItem>", GTK_STOCK_ABOUT */},
 };
 
 static int display_nmenu_items = (sizeof(display_menu_items) /
@@ -448,7 +482,6 @@ menus_set_tools_callback (const char * menu_name, GtkItemFactory *item_factory)
 static void
 menus_init(void)
 {
-  GtkWidget *menuitem;
   gchar *accelfilename;
   GList *cblist;
 
@@ -491,7 +524,7 @@ menus_init(void)
   display_menus = gtk_item_factory_get_widget(display_item_factory,
 					      "<Display>");
   gtk_menu_set_accel_path(GTK_MENU(display_menus), "<Display>/");
-
+  
   menus_set_tools_callback ("<Display>", NULL);
 
   gtk_menu_set_title(GTK_MENU(display_menus), _("Diagram Menu"));
@@ -652,6 +685,8 @@ menus_initialize_updatable_items (UpdatableMenuItems *items,
     items->paste = menus_get_item_from_path(path->str, factory);
     g_string_append (g_string_assign(path, display),"/Edit/Delete");
     items->edit_delete = menus_get_item_from_path(path->str, factory);
+    g_string_append (g_string_assign(path, display),"/Edit/Duplicate");
+    items->edit_duplicate = menus_get_item_from_path(path->str, factory);
 
     g_string_append (g_string_assign(path, display),"/Edit/Copy Text");
     items->copy_text = menus_get_item_from_path(path->str, factory);
@@ -704,7 +739,7 @@ menus_initialize_updatable_items (UpdatableMenuItems *items,
     g_string_append (g_string_assign(path, display),"/Objects/Properties...");
     items->properties = menus_get_item_from_path(path->str, factory);
     
-    g_string_free (path,FALSE);
+    g_string_free (path,TRUE);
 }
 
 
